==> ecs-patterns-1.108.1-sources.jar: software/amazon/awscdk/services/ecs/patterns/ScheduledEc2TaskDefinitionOptions.java <==
package software.amazon.awscdk.services.ecs.patterns;

/**
 * The properties for the ScheduledEc2Task using a task definition.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.30.0 (build adae23f)", date = "2021-06-11T15:15:33.414Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.patterns.$Module.class, fqn = "@aws-cdk/aws-ecs-patterns.ScheduledEc2TaskDefinitionOptions")
@software.amazon.jsii.Jsii.Proxy(ScheduledEc2TaskDefinitionOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ScheduledEc2TaskDefinitionOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The task definition to use for tasks in the service. One of image or taskDefinition must be specified.
     * <p>
     * [disable-awslint:ref-via-interface]
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.Ec2TaskDefinition getTaskDefinition();

    /**
     * @return a {@link Builder} of {@link ScheduledEc2TaskDefinitionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ScheduledEc2TaskDefinitionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ScheduledEc2TaskDefinitionOptions> {
        private software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition;

        /**
         * Sets the value of {@link ScheduledEc2TaskDefinitionOptions#getTaskDefinition}
         * @param taskDefinition The task definition to use for tasks in the service. One of image or taskDefinition must be specified. This parameter is required.
         *                       [disable-awslint:ref-via-interface]
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder taskDefinition(software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition) {
            this.taskDefinition = taskDefinition;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ScheduledEc2TaskDefinitionOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ScheduledEc2TaskDefinitionOptions build() {
            return new Jsii$Proxy(taskDefinition);
        }
    }

    /**
     * An implementation for {@link ScheduledEc2TaskDefinitionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ScheduledEc2TaskDefinitionOptions {
        private final software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.taskDefinition = software.amazon.jsii.Kernel.get(this, "taskDefinition", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.Ec2TaskDefinition.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.taskDefinition = java.util.Objects.requireNonNull(taskDefinition, "taskDefinition is required");
        }

        @Override
        public final software.amazon.awscdk.services.ecs.Ec2TaskDefinition getTaskDefinition() {
            return this.taskDefinition;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("taskDefinition", om.valueToTree(this.getTaskDefinition()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs-patterns.ScheduledEc2TaskDefinitionOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ScheduledEc2TaskDefinitionOptions.Jsii$Proxy that = (ScheduledEc2TaskDefinitionOptions.Jsii$Proxy) o;

            return this.taskDefinition.equals(that.taskDefinition);
        }

        @Override
        public final int hashCode() {
            int result = this.taskDefinition.hashCode();
            return result;
        }
    }
}

==> ecs-patterns-1.185.0-sources.jar: software/amazon/awscdk/services/ecs/patterns/ScheduledEc2TaskDefinitionOptions.java <==
package software.amazon.awscdk.services.ecs.patterns;

/**
 * The properties for the ScheduledEc2Task using a task definition.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ecs.*;
 * import software.amazon.awscdk.services.ecs.patterns.*;
 * Ec2TaskDefinition ec2TaskDefinition;
 * ScheduledEc2TaskDefinitionOptions scheduledEc2TaskDefinitionOptions = ScheduledEc2TaskDefinitionOptions.builder()
 *         .taskDefinition(ec2TaskDefinition)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.72.0 (build 4b8828b)", date = "2022-12-27T20:28:50.041Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.patterns.$Module.class, fqn = "@aws-cdk/aws-ecs-patterns.ScheduledEc2TaskDefinitionOptions")
@software.amazon.jsii.Jsii.Proxy(ScheduledEc2TaskDefinitionOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ScheduledEc2TaskDefinitionOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The task definition to use for tasks in the service. One of image or taskDefinition must be specified.
     * <p>
     * [disable-awslint:ref-via-interface]
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.Ec2TaskDefinition getTaskDefinition();

    /**
     * @return a {@link Builder} of {@link ScheduledEc2TaskDefinitionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ScheduledEc2TaskDefinitionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ScheduledEc2TaskDefinitionOptions> {
        software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition;

        /**
         * Sets the value of {@link ScheduledEc2TaskDefinitionOptions#getTaskDefinition}
         * @param taskDefinition The task definition to use for tasks in the service. One of image or taskDefinition must be specified. This parameter is required.
         *                       [disable-awslint:ref-via-interface]
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder taskDefinition(software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition) {
            this.taskDefinition = taskDefinition;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ScheduledEc2TaskDefinitionOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ScheduledEc2TaskDefinitionOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ScheduledEc2TaskDefinitionOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ScheduledEc2TaskDefinitionOptions {
        private final software.amazon.awscdk.services.ecs.Ec2TaskDefinition taskDefinition;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.taskDefinition = software.amazon.jsii.Kernel.get(this, "taskDefinition", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.Ec2TaskDefinition.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.taskDefinition = java.util.Objects.requireNonNull(builder.taskDefinition, "taskDefinition is required");
        }

        @Override
        public final software.amazon.awscdk.services.ecs.Ec2TaskDefinition getTaskDefinition() {
            return this.taskDefinition;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("taskDefinition", om.valueToTree(this.getTaskDefinition()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs-patterns.ScheduledEc2TaskDefinitionOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ScheduledEc2TaskDefinitionOptions.Jsii$Proxy that = (ScheduledEc2TaskDefinitionOptions.Jsii$Proxy) o;

            return this.taskDefinition.equals(that.taskDefinition);
        }

        @Override
        public final int hashCode() {
            int result = this.taskDefinition.hashCode();
            return result;
        }
    }
}
